@@ -7,6 +7,7 @@ from bemserver_core.model import TimeseriesProperty
 from bemserver_core.common import PropertyType
 
 from bemserver_api import AutoSchema, Schema, SortField
+from bemserver_api.extensions import ma_fields
 
 
 class TimeseriesPropertySchema(AutoSchema):
@@ -16,6 +17,7 @@ class TimeseriesPropertySchema(AutoSchema):
     id = msa.auto_field(dump_only=True)
     name = msa.auto_field(validate=ma.validate.Length(1, 80))
     value_type = ma.fields.Enum(PropertyType, metadata={"default": "string"})
+    unit_symbol = ma_fields.UnitSymbol(validate=ma.validate.Length(0, 20))
 
 
 class TimeseriesPropertyPutSchema(TimeseriesPropertySchema):
@@ -27,4 +29,4 @@ class TimeseriesPropertyQueryArgsSchema(Schema):
     sort = SortField(("name",))
     name = ma.fields.Str()
     value_type = ma.fields.Enum(PropertyType)
-    unit_symbol = ma.fields.Str()
+    unit_symbol = ma_fields.UnitSymbol()
