@@ -751,9 +751,9 @@ def timeseries_by_zones(app, zones, timeseries):
 
 
 @pytest.fixture
-def energy_sources(app):
+def energies(app):
     with OpenBar():
-        return [x.id for x in model.EnergySource.get()]
+        return [x.id for x in model.Energy.get()]
 
 
 @pytest.fixture
@@ -762,18 +762,24 @@ def energy_end_uses(app):
         return [x.id for x in model.EnergyEndUse.get()]
 
 
+@pytest.fixture
+def energy_production_technologies(app):
+    with OpenBar():
+        return [x.id for x in model.EnergyProductionTechnology.get()]
+
+
 @pytest.fixture
 def energy_consumption_timeseries_by_sites(app, timeseries, sites):
     with OpenBar():
         ectbs_1 = model.EnergyConsumptionTimeseriesBySite.new(
             site_id=sites[0],
-            source_id=1,
+            energy_id=1,
             end_use_id=1,
             timeseries_id=timeseries[0],
         )
         ectbs_2 = model.EnergyConsumptionTimeseriesBySite.new(
             site_id=sites[1],
-            source_id=2,
+            energy_id=2,
             end_use_id=2,
             timeseries_id=timeseries[1],
         )
@@ -786,13 +792,13 @@ def energy_consumption_timeseries_by_buildings(app, timeseries, buildings):
     with OpenBar():
         ectbs_1 = model.EnergyConsumptionTimeseriesByBuilding.new(
             building_id=buildings[0],
-            source_id=1,
+            energy_id=1,
             end_use_id=1,
             timeseries_id=timeseries[0],
         )
         ectbs_2 = model.EnergyConsumptionTimeseriesByBuilding.new(
             building_id=buildings[1],
-            source_id=2,
+            energy_id=2,
             end_use_id=2,
             timeseries_id=timeseries[1],
         )
@@ -800,6 +806,61 @@ def energy_consumption_timeseries_by_buildings(app, timeseries, buildings):
     return (ectbs_1.id, ectbs_2.id)
 
 
+@pytest.fixture
+def energy_production_timeseries_by_sites(app, timeseries, sites):
+    with OpenBar():
+        ectbs_1 = model.EnergyProductionTimeseriesBySite.new(
+            site_id=sites[0],
+            energy_id=1,
+            prod_tech_id=1,
+            timeseries_id=timeseries[0],
+        )
+        ectbs_2 = model.EnergyProductionTimeseriesBySite.new(
+            site_id=sites[1],
+            energy_id=2,
+            prod_tech_id=2,
+            timeseries_id=timeseries[1],
+        )
+        db.session.commit()
+    return (ectbs_1.id, ectbs_2.id)
+
+
+@pytest.fixture
+def energy_production_timeseries_by_buildings(app, timeseries, buildings):
+    with OpenBar():
+        ectbb_1 = model.EnergyProductionTimeseriesByBuilding.new(
+            building_id=buildings[0],
+            energy_id=1,
+            prod_tech_id=1,
+            timeseries_id=timeseries[0],
+        )
+        ectbb_2 = model.EnergyProductionTimeseriesByBuilding.new(
+            building_id=buildings[1],
+            energy_id=2,
+            prod_tech_id=2,
+            timeseries_id=timeseries[1],
+        )
+        db.session.commit()
+    return (ectbb_1.id, ectbb_2.id)
+
+
+@pytest.fixture
+def weather_timeseries_by_sites(app, timeseries, sites):
+    with OpenBar():
+        ectbs_1 = model.WeatherTimeseriesBySite.new(
+            site_id=sites[0],
+            parameter=model.WeatherParameterEnum.AIR_TEMPERATURE,
+            timeseries_id=timeseries[0],
+        )
+        ectbs_2 = model.WeatherTimeseriesBySite.new(
+            site_id=sites[1],
+            parameter=model.WeatherParameterEnum.RELATIVE_HUMIDITY,
+            timeseries_id=timeseries[1],
+        )
+        db.session.commit()
+    return (ectbs_1.id, ectbs_2.id)
+
+
 @pytest.fixture
 def st_cleanups_by_campaigns(app, campaigns):
     with OpenBar():
